==> eav_field-2.0.0.tar.gz: eav_field/src/Entity/EavValue.php <==
<?php

namespace Drupal\eav_field\Entity;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Entity\Annotation\ContentEntityType;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\entity\BundleFieldDefinition;

/**
 * @ContentEntityType(
 *   id = "eav_value",
 *   label = @Translation("EAV value"),
 *   base_table = "eav_value",
 *   entity_keys = {
 *     "id" = "vid",
 *     "uuid" = "uuid",
 *   },
 *   translatable = FALSE,
 *   revisionable = FALSE,
 *   fieldable = FALSE,
 *   handlers = {
 *     "form" = {
 *       "default" = "\Drupal\eav_field\Form\EavValueForm",
 *     },
 *   },
 *   links = {},
 * )
 */
class EavValue extends ContentEntityBase {

  /**
   * {@inheritDoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type); /** @var BaseFieldDefinition[] $fields */

    $fields['vid']->setLabel(t('Value ID'));

    $fields['aid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Attribute'))
      ->setSetting('target_type', 'eav_attribute')
      ->setRequired(TRUE)
      ->setDisplayOptions('form', [
        'type' => 'options_select',
      ]);

    $field_types = self::getFieldTypes();

    foreach ($field_types as $field_type => $field_settings) {
      // Used BundleFieldDefinition without BaseFieldDefinition to solve the following problem:
      // when value field configured as single-value it does not save values, because Drupal try
      // save data in "eav_value" table instead "eav_value__*_value" table.
      $fields[$field_type . '_value'] = BundleFieldDefinition::create($field_type)
        ->setLabel(t('Value'))
        ->setCardinality(FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED);

      if ($field_settings) {
        $fields[$field_type . '_value']->setSettings($field_settings);
      }
    }

    return $fields;
  }

  /**
   * Return supported value field types.
   */
  public static function getFieldTypes() {
    $field_types = [
      'string' => ['max_length' => 1000],
      'string_long' => [],
      'integer' => [],
      'decimal' => [],
      'boolean' => [],
      'entity_reference' => [],
      'list_string' => [],
      'list_integer' => [],
    ];

    \Drupal::moduleHandler()->alter('eav_field_types', $field_types);

    return $field_types;
  }

  /**
   * Return attribute id.
   *
   * @return integer
   */
  public function getAttributeId() {
    return $this->get('aid')->target_id;
  }

  /**
   * Return attribute entity.
   *
   * @return EavAttribute
   */
  public function getAttributeEntity() {
    return $this->get('aid')->entity;
  }

  /**
   * Return value field name.
   *
   * @return string
   */
  public function getValueFieldName() {
    if ($attribute = $this->getAttributeEntity()) {
      return $attribute->getValueFieldName();
    }
    return NULL;
  }

  /**
   * Return value field items.
   *
   * @return FieldItemListInterface
   */
  public function getValueFieldItems() {
    if ($attribute = $this->getAttributeEntity()) {
      return $this->get($attribute->getValueFieldName());
    }
    return NULL;
  }

  /**
   * Return values field value.
   *
   * @return array
   */
  public function getValueFieldValue() {
    if ($value_field_items = $this->getValueFieldItems()) {
      return $value_field_items->getValue();
    }
    return NULL;
  }

  /**
   * Format value field in selected formatter.
   */
  public function viewValueField() {
    $attribute = $this->getAttributeEntity();

    if ($attribute && ($formatter_type = $attribute->getValueFormatterType())) {
      $value_field_build = $this->getValueFieldItems()->view([
        'type' => $formatter_type,
        'settings' => $attribute->getValueFormatterSettings(),
        'label' => 'hidden',
      ]);
    }
    else {
      $value_field_build = $this->getValueFieldItems()->getString();
    }

    return $value_field_build;
  }

}

==> eav_field-2.0.1.tar.gz: eav_field/src/Entity/EavValue.php <==
<?php

namespace Drupal\eav_field\Entity;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Entity\Annotation\ContentEntityType;
use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\entity\BundleFieldDefinition;

/**
 * @ContentEntityType(
 *   id = "eav_value",
 *   label = @Translation("EAV value"),
 *   base_table = "eav_value",
 *   entity_keys = {
 *     "id" = "vid",
 *     "uuid" = "uuid",
 *   },
 *   translatable = FALSE,
 *   revisionable = FALSE,
 *   fieldable = FALSE,
 *   handlers = {
 *     "form" = {
 *       "default" = "\Drupal\eav_field\Form\EavValueForm",
 *     },
 *   },
 *   links = {},
 * )
 */
class EavValue extends ContentEntityBase {

  /**
   * {@inheritDoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type); /** @var BaseFieldDefinition[] $fields */

    $fields['vid']->setLabel(t('Value ID'));

    $fields['aid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Attribute'))
      ->setSetting('target_type', 'eav_attribute')
      ->setRequired(TRUE)
      ->setDisplayOptions('form', [
        'type' => 'options_select',
      ]);

    $field_types = self::getFieldTypes();

    foreach ($field_types as $field_type => $field_settings) {
      // Used BundleFieldDefinition without BaseFieldDefinition to solve the following problem:
      // when value field configured as single-value it does not save values, because Drupal try
      // save data in "eav_value" table instead "eav_value__*_value" table.
      $fields[$field_type . '_value'] = BundleFieldDefinition::create($field_type)
        ->setLabel(t('Value'))
        ->setCardinality(FieldStorageDefinitionInterface::CARDINALITY_UNLIMITED);

      if ($field_settings) {
        $fields[$field_type . '_value']->setSettings($field_settings);
      }
    }

    return $fields;
  }

  /**
   * Return supported value field types.
   */
  public static function getFieldTypes(): array {
    $field_types = [
      'string' => ['max_length' => 1000],
      'string_long' => [],
      'integer' => [],
      'decimal' => [],
      'boolean' => [],
      'entity_reference' => [],
      'list_string' => [],
      'list_integer' => [],
    ];

    \Drupal::moduleHandler()->alter('eav_field_types', $field_types);

    return $field_types;
  }

  /**
   * Return attribute id.
   */
  public function getAttributeId(): ?int {
    return $this->get('aid')->target_id;
  }

  /**
   * Return attribute entity.
   */
  public function getAttributeEntity(): ?EavAttribute {
    return $this->get('aid')->entity;
  }

  /**
   * Return value field name.
   */
  public function getValueFieldName(): ?string {
    if ($attribute = $this->getAttributeEntity()) {
      return $attribute->getValueFieldName();
    }
    return NULL;
  }

  /**
   * Return value field items.
   */
  public function getValueFieldItems(): ?FieldItemListInterface {
    if ($attribute = $this->getAttributeEntity()) {
      return $this->get($attribute->getValueFieldName());
    }
    return NULL;
  }

  /**
   * Return values field value.
   */
  public function getValueFieldValue(): ?array {
    if ($value_field_items = $this->getValueFieldItems()) {
      return $value_field_items->getValue();
    }
    return NULL;
  }

  /**
   * Format value field in selected formatter.
   *
   * @return array|string
   */
  public function viewValueField() {
    $attribute = $this->getAttributeEntity();

    if ($attribute && ($formatter_type = $attribute->getValueFormatterType())) {
      $value_field_build = $this->getValueFieldItems()->view([
        'type' => $formatter_type,
        'settings' => $attribute->getValueFormatterSettings(),
        'label' => 'hidden',
      ]);
    }
    else {
      $value_field_build = $this->getValueFieldItems()->getString();
    }

    return $value_field_build;
  }

}
